.. -*- coding: utf-8 -*-

===============================
``pybill.lib.entities`` package
===============================

.. automodule:: pybill.lib.entities

``addresses`` module
====================

.. automodule:: pybill.lib.entities.addresses

``accounting_docs`` sub-package
===============================

.. automodule:: pybill.lib.entities.accounting_docs
